@@ -158,7 +158,11 @@ class GVDialer(object):
 			_moduleLogger.exception("Translating error: %s" % str(e))
 			raise NetworkError("%s is not accesible" % self._loginURL)
 		galxTokens = self._galxRe.search(tokenPage)
-		galxToken = galxTokens.group(1)
+		if galxTokens is not None:
+			galxToken = galxTokens.group(1)
+		else:
+			galxToken = ""
+			_moduleLogger.debug("Could not grab GALX token")
 
 		loginPostData = urllib.urlencode({
 			'Email' : username,
